@@ -338,10 +338,14 @@ class Client(ClientBase):
     vnfd_path = '/vnfds/%s'
     vnfs_path = '/vnfs'
     vnf_path = '/vnfs/%s'
+    vnf_scale_path = '/vnfs/%s/actions'
 
     vims_path = '/vims'
     vim_path = '/vims/%s'
 
+    events_path = '/events'
+    event_path = '/events/%s'
+
     # API has no way to report plurals, so we have to hard code them
     # EXTED_PLURALS = {}
 
@@ -378,6 +382,10 @@ class Client(ClientBase):
     @APIParamsCall
     def create_vnfd(self, body=None):
         if body is not None:
+            if ("tosca_definitions_version" not in
+               body[self._VNFD]['attributes']['vnfd']):
+                _logger.warning("VNFD legacy templates are deprecated. Please "
+                                "use NFV TOSCA templates.")
             body[self._VNFD]['service_types'] = [{'service_type': 'vnfd'}]
             body[self._VNFD]['infra_driver'] = 'heat'
             body[self._VNFD]['mgmt_driver'] = 'noop'
@@ -417,6 +425,10 @@ class Client(ClientBase):
     def update_vnf(self, vnf, body=None):
         return self.put(self.vnf_path % vnf, body=body)
 
+    @APIParamsCall
+    def scale_vnf(self, vnf, body=None):
+        return self.post(self.vnf_scale_path % vnf, body=body)
+
     @APIParamsCall
     def show_vim(self, vim, **_params):
         return self.get(self.vim_path % vim, params=_params)
@@ -438,3 +450,40 @@ class Client(ClientBase):
     @APIParamsCall
     def list_vims(self, retrieve_all=True, **_params):
         return self.list('vims', self.vims_path, retrieve_all, **_params)
+
+    @APIParamsCall
+    def list_events(self, retrieve_all=True, **_params):
+        events = self.list('events', self.events_path, retrieve_all,
+                           **_params)
+        return events
+
+    @APIParamsCall
+    def list_vnf_events(self, retrieve_all=True, **_params):
+        _params['resource_type'] = 'vnf'
+        events = self.list('events', self.events_path, retrieve_all,
+                           **_params)
+        vnf_events = {}
+        vnf_events['vnf_events'] = events['events']
+        return vnf_events
+
+    @APIParamsCall
+    def list_vnfd_events(self, retrieve_all=True, **_params):
+        _params['resource_type'] = 'vnfd'
+        events = self.list('events', self.events_path, retrieve_all,
+                           **_params)
+        vnfd_events = {}
+        vnfd_events['vnfd_events'] = events['events']
+        return vnfd_events
+
+    @APIParamsCall
+    def list_vim_events(self, retrieve_all=True, **_params):
+        _params['resource_type'] = 'vim'
+        events = self.list('events', self.events_path, retrieve_all,
+                           **_params)
+        vim_events = {}
+        vim_events['vim_events'] = events['events']
+        return vim_events
+
+    @APIParamsCall
+    def show_event(self, event_id, **_params):
+        return self.get(self.event_path % event_id, params=_params)
